Struct riff_wave::WaveReader [] [src]

pub struct WaveReader<T> where T: Read + Seek {
    pub pcm_format: PcmFormat,
    // some fields omitted
}

Helper struct that takes ownership of a reader and can be used to read data from a PCM wave file.

Fields

pcm_format: PcmFormat

Represents the PCM format for this wave file.

Methods

impl<T> WaveReader<T> where T: Read + Seek
[src]

fn new(reader: T) -> ReadResult<WaveReader<T>>

Returns a new wave reader for the given reader.

fn read_samples_as_u8(&mut self, buf: &mut [u8]) -> ReadResult<usize>